@@ -18,6 +18,22 @@ import collections
 
 SLICE_ALL = slice(None)
 
+
+def is_iterable(obj):
+    """
+    Are we being asked to look up a list of things, instead of a single thing?
+    We check for the `__iter__` attribute so that this can cover types that
+    don't have to be known by this module, such as NumPy arrays.
+
+    Strings, however, should be considered as atomic values to look up, not
+    iterables.
+
+    We don't need to check for the Python 2 `unicode` type, because it doesn't
+    have an `__iter__` attribute anyway.
+    """
+    return hasattr(obj, '__iter__') and not isinstance(obj, str)
+
+
 class OrderedSet(collections.MutableSet):
     """
     An OrderedSet is a custom MutableSet that remembers its order, so that
@@ -52,7 +68,7 @@ class OrderedSet(collections.MutableSet):
                 return OrderedSet(result)
             else:
                 return result
-        elif hasattr(index, '__iter__'):
+        elif is_iterable(index):
             return OrderedSet([self.items[i] for i in index])
         else:
             raise TypeError("Don't know how to index an OrderedSet by %r" %
@@ -88,10 +104,10 @@ class OrderedSet(collections.MutableSet):
         Get the index of a given entry, raising an IndexError if it's not
         present.
 
-        `key` can be an iterable of entries, in which case this returns a list
-        of indices.
+        `key` can be an iterable of entries that is not a string, in which case
+        this returns a list of indices.
         """
-        if hasattr(key, '__iter__'):
+        if is_iterable(key):
             return [self.index(subkey) for subkey in key]
         return self.map[key]
 
